.col {
    display: flex;
    /* flex-wrap: wrap; */
    flex-direction: column;
    align-items: flex-start;
    gap: 1rem;
    padding: 1rem;
}

.row {
    display: flex;
    /* flex-wrap: wrap; */
    flex-direction: row;
    align-items: flex-start;
    gap: 1rem;
    padding: 1rem;
}


.toastgrid {
    display: flex;
    flex-direction: column;
    max-width: 100%;
    gap: 1rem;
    padding: 1rem;
}