<!DOCTYPE html>
<html lang="en" data-theme="light">

<head>
    <link href="https://cdn.jsdelivr.net/npm/daisyui@3.9.4/dist/full.css" rel="stylesheet" type="text/css">
    <script src="https://cdn.tailwindcss.com"></script>
    <script src="https://uicdn.toast.com/grid/latest/tui-grid.js"></script>
    <meta charset="utf-8">
    <title>uiwiz</title>
    <!-- toast ui grid -->
    <link rel="stylesheet" href="https://uicdn.toast.com/grid/latest/tui-grid.css" />
    
    <link href="/static/app.css" rel="stylesheet" type="text/css" />
    <link href="/static/codehighlight.css" rel="stylesheet" type="text/css" />
</head>

<body>
    <div id="content">
        {% for element in root_element %}{{ element | safe}}{% endfor %}
    </div>
    <div id="toast" class="toast toast-top toast-end">
    </div>

    <script src="https://code.jquery.com/jquery-3.7.1.min.js"
        integrity="sha256-/JqT3SQfawRcv/BIHPThkBvs0OEvtFFmqPF/lYI/Cxo=" crossorigin="anonymous"></script>
    <script src="https://unpkg.com/htmx.org@1.9.6"></script>
    <script src="https://unpkg.com/htmx.org/dist/ext/json-enc.js"></script>
    <script>
        container = document.getElementById("toast");
        container.addEventListener("DOMNodeInserted", removeAfterDelay, false);

        function removeAfterDelay(event) {
            $(event.target).delay(1500).queue(() => {
                $(event.target).remove();
                $(event.target).dequeue();
            });
        }
    </script>    
</body>

</html>